@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * gtkchem3dviewer.c 
  *
- * Copyright (C) 2003-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2003-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,7 +35,7 @@
 #endif
 #include <sstream>
 #include <libintl.h>
-#include <locale.h>
+#include <clocale>
 #define _(String) gettext(String)
 #include <openbabel/mol.h>
 #include <openbabel/obconversion.h>
